var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.exportMetadataPackage = void 0;
const fs = require("fs");
const fsExtra = require("fs-extra");
const jszip = require("jszip");
const path = require("path");
const teams_manifest_1 = require("@microsoft/teams-manifest");
/* global console */
function exportMetadataPackage(output = "", manifest = "manifest.json") {
    return __awaiter(this, void 0, void 0, function* () {
        const manifestPath = path.resolve(manifest);
        const zip = yield createZip(manifestPath);
        if (output === "") {
            output = path.join(path.dirname(manifestPath), "manifest.zip");
        }
        yield saveZip(zip, output);
        return Promise.resolve(output);
    });
}
exports.exportMetadataPackage = exportMetadataPackage;
function createZip(manifestPath = "manifest.json") {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const zip = new jszip();
        if (fs.existsSync(manifestPath)) {
            const manifestData = fs.readFileSync(manifestPath);
            zip.file("manifest.json", manifestData);
        }
        else {
            throw new Error(`The file '${manifestPath}' does not exist`);
        }
        // Need json manifest manipulation before this can work.
        const manifest = yield teams_manifest_1.ManifestUtil.loadFromPath(manifestPath);
        addIconFile((_a = manifest.icons) === null || _a === void 0 ? void 0 : _a.color, zip);
        addIconFile((_b = manifest.icons) === null || _b === void 0 ? void 0 : _b.outline, zip);
        return Promise.resolve(zip);
    });
}
function addIconFile(iconPath, zip) {
    if (iconPath && !iconPath.startsWith("https://")) {
        const filePath = path.resolve(iconPath);
        if (fs.existsSync(filePath)) {
            zip.file(iconPath, fs.readFileSync(filePath));
        }
    }
}
function saveZip(zip, outputPath) {
    return __awaiter(this, void 0, void 0, function* () {
        outputPath = path.resolve(outputPath);
        fsExtra.ensureDirSync(path.dirname(outputPath));
        return new Promise((fulfill) => zip
            .generateNodeStream({ type: "nodebuffer", streamFiles: true })
            .pipe(fs.createWriteStream(outputPath))
            .on("finish", function () {
            // JSZip generates a readable stream with a "end" event,
            // but is piped here in a writable stream which emits a "finish" event.
            console.log(`Manifest package saved to ${outputPath}`);
            fulfill();
        }));
    });
}
//# sourceMappingURL=export.js.map